<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Proofreading
 * @subpackage Proofreading/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the proofreading, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Proofreading
 * @subpackage Proofreading/admin
 * @author     Your Name <email@example.com>
 */
class Proofreading_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Proofreading_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Proofreading_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/proofreading-admin.css', array(), $this->version, 'all' );
		
		wp_register_style( 'font-awesome', 'https://use.fontawesome.com/releases/v5.0.6/css/all.css' );
		wp_enqueue_style( 'font-awesome' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Proofreading_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Proofreading_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/proofreading-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	/**
	 * Define menu items for backend console.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	public function admin_menu() {
		
		require_once plugin_dir_path( __FILE__ ) . 'partials/proofreading-admin-display.php';
		
		add_options_page(
			__("Proofreading", "proofreading"),
			__("Proofreading", "proofreading"),
			"manage_options",
			"proofreading/settings.php",
			"proofreading_admin_page_handler",
			"dashicons-tickets"
		);
		add_options_page(
			__("Proofreading", "proofreading"),
			"",
			"manage_options",
			"proofreading/about.php",
			"proofreading_admin_page_handler",
			"dashicons-tickets"
		);
		
	}
	
	public function admin_bar_menu($wp_admin_bar) {
		
		$args = array(
			'id'     => 'menu_id',
			'title'	=>	'title',
			'meta'   => array( 'class' => 'first-toolbar-group' ),
		);
		$wp_admin_bar->add_node( $args );	

		// add child items
		$args = array();
		array_push($args,array(
			'id'		=>	'id_sub',
			'title'		=>	'title_sub',
			'href'		=>	'sub_link',
			'parent'	=>	'menu_id',
		));
		
		foreach( $args as $each_arg)	{
			$wp_admin_bar->add_node($each_arg);
		}
	}
	
	public function load_metaboxes() {
		
		if( !class_exists('ProofreadingMetaBox') )
			require_once plugin_dir_path( __FILE__ ) . 'includes/class-proofreading-metabox.php';
		
		new ProofreadingMetaBox();
		
	}
}