window.webdev_ajax = ( function( window, document, $ ){
	var app = {};

	app.cache = function(){
		app.$analyze_button = $( '#proofreading_analyze' );
		app.$spinner = $( '#proofreading_box .spinner' );
		app.$analyze_result = $( '#proofreading_analyze_results' );
	};

	app.init = function(){
		app.cache();
		app.$analyze_button.on( 'click', app.analyze_button_handler );
	};

	app.post_ajax_analyze = function( post_text, language ){
		
		app.$spinner.css('visibility', 'visible');
		
		var post_data = {
			action	   : 'analyze',
			nonce      : proofreading.nonce,
			post_text  : post_text,
			language   : language
		};

		$.post(
			ajaxurl,
			post_data,
			function( response_data ){
				if( response_data.success ){
					proofreading.nonce = response_data.data.nonce;
					
					var response = JSON.parse(response_data.data.result);
					if (response == null || response.error != null || response.matches == null)
					{
						var error = '';
						if (response == null)
							error = proofreading.trans_result_error;
						else{
							switch(response.error){
								case 'TOO_MANY_ERRORS' : error = proofreading.trans_result_error_too_many_errors; break;
								case 'INVALID_REQUEST' : error = proofreading.trans_result_error_invalid_request; break;
								default: error = proofreading.trans_result_error; break;
							}
						}
						app.$analyze_result.html('<p class="proofreading_error">' + error + '</p>');
					}
					else{
						if (response.matches.length == 0)
							app.$analyze_result.html('<p id="proofreading_success">' + proofreading.trans_result_ok + '</p>');
						else{
							var result_text = '<p class="proofreading_error" id="proofreading_errors_number">' + proofreading.trans_result_errors_to_correct + ': <span>' + response.matches.length + '</span></p>'+
								'<p id="proofreading_hidden_errors_number">' + proofreading.trans_result_errors_hidden + ': <span></span></p>'+
								'<ul class="proofreading_corrections">';
							var post_text = tmce_getContent('content', {format : 'text'});
							
							response.matches.forEach(function(match) {
								result_text = result_text + '<li>'+
										'<span class="proofreading_correction_button"></span> '+
										'<pre class="proofreading_correction_text">' + match.context.text.substring(match.context.offset, match.context.offset + match.context.length) + '</pre>'+
										'<div class="proofreading_correction_message" data-errorcategory="' + match.rule.category.id + '">' + match.message + '</div>'+
										'<div class="proofreading_correction_sentence" style="display:none">' + match.sentence + '</div>'+
									'</li>';
								return;
								
							});
							app.$analyze_result.html(result_text + '</ul>');
							
							var btnShow = $('<button/>', {
								title: proofreading.trans_btn_show_error,
								class: 'fa fa-align-left',
								click: function (e) {
									e.preventDefault();
									var sentence = $(this).closest('li').find('.proofreading_correction_sentence').html();
									tmce_setSelection('content', sentence);
								}
							});
							
							var btnHide = $('<button/>', {
								title: proofreading.trans_btn_hide_error,
								class: 'fa fa-eye-slash',
								click: function (e) {
									e.preventDefault();
									$(this).closest('li').fadeOut('medium', function(){
										updateCounters();
									});
								}
							});
							
							var btnHideCategory = $('<button/>', {
								title: proofreading.trans_btn_hide_error_category,
								class: 'fa fa-object-group',
								style: 'margin-left:10px',
								click: function (e) {
									var category = $(this).closest('li').find('.proofreading_correction_message').data('errorcategory');
									console.log('cat: '+ category);
									$(this).closest('ul').find('li').each(function(){
										var exist = $(this).find(".proofreading_correction_message[data-errorcategory='"+ category +"']").length;
										if (exist) $(this).fadeOut('medium', function(){
											updateCounters();
										});
									});
									e.preventDefault();
								}
							});
							
							$('.proofreading_correction_button')
								.prepend(btnHideCategory)
								.prepend(btnHide)
								.prepend(btnShow);
							
							var btnShowHidden = $('<button/>', {
								title: proofreading.trans_btn_show_error_hidden,
								class: 'fa fa-eye',
								style: 'margin-left:10px',
								click: function (e) {
									e.preventDefault();
									$('.proofreading_corrections li').each(function(){
										$(this).fadeIn('medium');
									});
									updateCounters();
								}
							});
							$('#proofreading_hidden_errors_number').append(btnShowHidden);
						}
						
						var node = tinymce.activeEditor.selection.getNode();
					}
					
				} else {
					app.$analyze_result.html('<p class="proofreading_error">Generic error</p>');
				}
				
				app.$spinner.css('visibility', 'hidden');
				
				function updateCounters() {
					var number = $('ul.proofreading_corrections li').filter(":visible").length;
					$('#proofreading_errors_number span').html(number);
					
					var number_hidden = $('ul.proofreading_corrections li').filter(":hidden").length;
					if (number_hidden > 0){
						$('#proofreading_hidden_errors_number span').html(number_hidden);
						$('#proofreading_hidden_errors_number').show();
					}
					else
						$('#proofreading_hidden_errors_number').hide();
				}
			},
			'json' )
	};

	app.analyze_button_handler = function( evt ){
		evt.preventDefault();
		
		var post_text = tmce_getContent('content', {format : 'text'});
		var language = jQuery('#language').val();
		app.post_ajax_analyze( post_text, language );
	};

	$(document).ready( app.init );

	return app;

})( window, document, jQuery );



// https://gist.github.com/RichiUfo/db81eee918c8112f20c2d2b3cb1781f0
function tmce_getContent(editor_id, format) {
	if ( typeof editor_id == 'undefined' ) editor_id = wpActiveEditor;

	if ( jQuery('#wp-'+editor_id+'-wrap').hasClass('tmce-active') && tinyMCE.get(editor_id) ) {
		return tinyMCE.get(editor_id).getContent(format);
	}
}

function tmce_setSelection(editor_id, phrase) {
	if ( typeof editor_id == 'undefined' ) editor_id = wpActiveEditor;
	
	if ( jQuery('#wp-'+editor_id+'-wrap').hasClass('tmce-active') && tinyMCE.get(editor_id) ) {
		
		var ed = tinyMCE.get(editor_id);
		phrase = phrase.replace('\n',' ');
		var marker = $(ed.getBody()).find('p:contains('+ phrase +')');
		ed.selection.select(marker.get(0)).focus();
	}
}